classdef plot_buffered_common < fb_abstract.line_plot
% this is the super class for buffered plots. Hopefully, this class will
% one day unify 'plot_buffered' and 'plot_buffered_new'

    properties (SetAccess = public, GetAccess = public)
        % you can shift the buffers manually
        shift_buffers_by = 0;
    end     
    
    %% public methods - none. We do not provide a constructor, because this
    % is an abstract class.
    methods

        function set.shift_buffers_by(obj, newvalue)
            obj.shift_buffers_by = newvalue;
            if is_plot(obj) == 0
                return;
            end
            update_plot(obj);
        end
        
    end
    
    %% API methods used by other plugins / classes
    methods (Access = public, Hidden = true)
        
        function time_in_sec = transfer_buffers_to_time(obj, nbr_of_buffers)
            buffers = 1:nbr_of_buffers;
            time_in_sec = obj.transfer_single_buffer_to_time(buffers);
        end
        
        function time_in_sec = transfer_single_buffer_to_time(obj, buffer)
            time_in_sec = obj.transfer_single_buffer_to_sample(buffer) / obj.Scanrate;
        end
        
    end
    
    %% ABSTRACT METHOD
    methods (Abstract = true, Access = public, Hidden = true)
        time_in_samplingrate = transfer_single_buffer_to_sample(obj, buffer);
    end
    
    methods (Access = protected, Hidden = true)
        function timepoints = class_return_samplenumbers(obj)
            
            % if data is empty, then we might need to run the threshold 
            % function
            data = obj.transformed_data;
            if isempty(data)
                data = obj.threshold_function();
            end
            
            % data is still empty 
            % 1. no threshold function defined
            % 2. transform_function wasn't executed.
            if isempty(data) == 1
                timepoints = [];
                disp('Please make sure you run the "transform_function" first.');
                return;
            end
            
            nbr_buffers = size(data, 2);
            x_buffered = obj.transfer_buffers_to_time(nbr_buffers);
            timepoints = (x_buffered) * obj.Scanrate;
        end
    end
    
end
%% EOF
