function [indices, indices_off] = clean_up_indices(obj, indices_on_orig, indices_off_orig)
% CLEAN UP INDICES

    % If indices_on_orig or indices_off_orig is empty, then this function
    % will never be called. See fb_abstract.tag.plugin_tag_function()
    %

    %% remove multiple on / offsets, i.e. extract the beginnings and ends
    % of all threshold crossing periods.
    if obj.TAG_TRANSFORM_CLEAN == 1
        
        %% get positive threshold crossings
        h = diff(indices_on_orig);
        indices = [indices_on_orig(1) indices_on_orig(find(h > 1) + 1)];
        
        %% get negative threshold crossings
        h = diff(indices_off_orig);
        indices_off = [indices_off_orig(1) indices_off_orig(find(h > 1) + 1)];
        
        %% remove negative threshold crossings before the first positive
        % threshold crossing
        while indices_off(1) < indices(1)
            indices_off = indices_off(2:end);
        end
        
        %% filter out all false ON settings
        % see also fb_abstract.tag.plugin_tag_find_indices
        if ~isempty(obj.TAG_THRESHOLD_UP)
            nbr_found = 0;
            for i = 1 : numel(indices_off)
                this_off = indices_off(i);
                if nbr_found == 0
                    cands = indices < this_off;
                else
                    cands = indices(nbr_found+1:end) < this_off;
                end
                
                found = find(cands)+nbr_found;
                if numel(found) > 1
                    indices(found) = [];
                    indices_off(i) = nan;
                else
                    nbr_found = nbr_found + 1;
                end
                
            end
            
            indices_off(isnan(indices_off)) = [];
            
        end
        
    %% keep all above / below threshold indices
    else
        indices = indices_on_orig;
        indices_off = indices_off_orig;
    end
    
end
%% EOF
