function extract_data(obj, data, nbr_TAG_INDICES)
% EXTRACT DATA AROUND TAG_INDICES

    size_data = size(data, 2);
    obj.TAG_FILE_LENGTH_SAMPLES = size_data;
    obj.TAG_DATA = cell(1, nbr_TAG_INDICES);
    WIN_SIZE = obj.TAG_PRESAMPLES + obj.TAG_POSTSAMPLES;

    %% extract the data around the indices
    for i = 1 : nbr_TAG_INDICES

        % point of threshold crossing
        this_index = obj.TAG_INDICES(i);

        % take all indices before and after this point, add one to
        % the start, because the total size should be
        % TAG_PRESAMPLES + TAG_POSTSAMPLES
        samples_to_keep = this_index - obj.TAG_PRESAMPLES + 1 : this_index + obj.TAG_POSTSAMPLES;

        % make sure that these point to not overlap with either the
        % beginning or the end of the file.
        this_data = data(:, samples_to_keep(samples_to_keep > 0 & samples_to_keep < size_data));

        if obj.TAG_RETURN_WHOLE_BUFFERS_ONLY == 1 && size(this_data, 2) < WIN_SIZE
            obj.TAG_INDICES(i) = nan;
            obj.TAG_INDICES_OFF(i) = nan;

            if obj.debug == 1
                disp('Skipping this overlapping buffer.');
            end
            continue;
        end

        obj.TAG_DATA{i} = this_data;
    end

    %% REMOVE INVALID INDICES & BUFFERS
    invalid = find(isnan(obj.TAG_INDICES));
    obj.TAG_DATA(invalid) = [];
    obj.TAG_INDICES(invalid) = [];
    obj.TAG_INDICES_OFF(invalid) = [];

    %% CHECK IF THERE ARE ANY CROSSING LEFT
    if isempty(obj.TAG_INDICES)
        obj.TAG_FOUND = 0;
    end

    %% TRANSFORM DATA TO INT16 IF NEEDED and ORIGINAL data is
    % double
    if obj.TAG_RETURN_DATA_AS_INT16 == 1 && obj.TAG_DATA_TYPE == 1
        obj.TAG_DATA = cellfun(@(x) int16(2^15/obj.TAG_TRANSFORM_DATA_DYNAMIC_RANGE*x), obj.TAG_DATA, 'UniformOutput', 0);
    end
    
end
%% EOF
