function tag_data(obj, data)
% tagging function - 'data' is a mandatory input because I don't want users
% to accidentally use an 'incorrect' version of 'obj.data'.

    if nargin < 2
        disp('Usage: tag_data(data)');
        obj.TAG_QUIT = 1;
        return;
    end

    %% RUN CHECKS BEFORE calling the tag function
    run_checks(obj, data);
    if obj.TAG_QUIT == 1
        return;
    end

    %% RUN THE TAGGING CODE
    
    % indicate that we are calling plugin_tag_function(). this is important
    % for certain transform_functions()
    obj.TAG_DATA_RUNNING = 1;
    
    try
        obj.plugin_tag_function(data);
    catch me
        obj.show_error(me.message, mfilename, me.stack, obj.Name, 'tag_function()', me.identifier);
    end

    % tagging has finished
    obj.TAG_DATA_RUNNING = 0;
    
end
%% EOF
